/****************************************************************************
** Meta object code from reading C++ file 'MainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konsole-26.07.90/src/MainWindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Konsole10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Konsole::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN7Konsole10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konsole::MainWindow",
        "newWindowRequest",
        "",
        "QExplicitlySharedDataPointer<Profile>",
        "profile",
        "directory",
        "ContainerInfo",
        "container",
        "terminalsDetached",
        "ViewSplitter*",
        "splitter",
        "QHash<TerminalDisplay*,Session*>",
        "sessionsMap",
        "saveNewToolbarConfig",
        "cloneTab",
        "newWindow",
        "showManageProfilesDialog",
        "activateMenuBar",
        "showSettingsDialog",
        "showProfilePage",
        "showShortcutsDialog",
        "newFromProfile",
        "newInContainer",
        "activeViewChanged",
        "SessionController*",
        "controller",
        "disconnectController",
        "activeViewTitleChanged",
        "ViewProperties*",
        "rebuildNewTabMenu",
        "configureNotifications",
        "setBlur",
        "blur",
        "updateWindowIcon",
        "updateWindowCaption",
        "updateProgress",
        "openUrls",
        "QList<QUrl>",
        "urls",
        "setProfileList",
        "ProfileList*",
        "list",
        "setContainerList",
        "ContainerList*",
        "applyKonsoleSettings",
        "applyThemeProfile",
        "activationRequest",
        "xdgActivationToken",
        "updateUseTransparency",
        "viewFullScreen",
        "fullScreen"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newWindowRequest'
        QtMocHelpers::SignalData<void(const QExplicitlySharedDataPointer<Profile> &, const QString &, const ContainerInfo &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'terminalsDetached'
        QtMocHelpers::SignalData<void(ViewSplitter *, QHash<TerminalDisplay*,Session*>)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'saveNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'cloneTab'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newWindow'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showManageProfilesDialog'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateMenuBar'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSettingsDialog'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'showSettingsDialog'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'showShortcutsDialog'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newFromProfile'
        QtMocHelpers::SlotData<void(const QExplicitlySharedDataPointer<Profile> &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'newInContainer'
        QtMocHelpers::SlotData<void(const ContainerInfo &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'activeViewChanged'
        QtMocHelpers::SlotData<void(SessionController *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'disconnectController'
        QtMocHelpers::SlotData<void(SessionController *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'activeViewTitleChanged'
        QtMocHelpers::SlotData<void(ViewProperties *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'rebuildNewTabMenu'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureNotifications'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setBlur'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'updateWindowIcon'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowCaption'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateProgress'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openUrls'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'setProfileList'
        QtMocHelpers::SlotData<void(ProfileList *)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'setContainerList'
        QtMocHelpers::SlotData<void(ContainerList *)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 41 },
        }}),
        // Slot 'applyKonsoleSettings'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyThemeProfile'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activationRequest'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'updateUseTransparency'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'viewFullScreen'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 50 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN7Konsole10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konsole::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Konsole10MainWindowE_t>.metaTypes,
    nullptr
} };

void Konsole::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newWindowRequest((*reinterpret_cast<std::add_pointer_t<QExplicitlySharedDataPointer<Profile>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ContainerInfo>>(_a[3]))); break;
        case 1: _t->terminalsDetached((*reinterpret_cast<std::add_pointer_t<ViewSplitter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QHash<TerminalDisplay*,Session*>>>(_a[2]))); break;
        case 2: _t->saveNewToolbarConfig(); break;
        case 3: _t->cloneTab(); break;
        case 4: _t->newWindow(); break;
        case 5: _t->showManageProfilesDialog(); break;
        case 6: _t->activateMenuBar(); break;
        case 7: _t->showSettingsDialog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->showSettingsDialog(); break;
        case 9: _t->showShortcutsDialog(); break;
        case 10: _t->newFromProfile((*reinterpret_cast<std::add_pointer_t<QExplicitlySharedDataPointer<Profile>>>(_a[1]))); break;
        case 11: _t->newInContainer((*reinterpret_cast<std::add_pointer_t<ContainerInfo>>(_a[1]))); break;
        case 12: _t->activeViewChanged((*reinterpret_cast<std::add_pointer_t<SessionController*>>(_a[1]))); break;
        case 13: _t->disconnectController((*reinterpret_cast<std::add_pointer_t<SessionController*>>(_a[1]))); break;
        case 14: _t->activeViewTitleChanged((*reinterpret_cast<std::add_pointer_t<ViewProperties*>>(_a[1]))); break;
        case 15: _t->rebuildNewTabMenu(); break;
        case 16: _t->configureNotifications(); break;
        case 17: _t->setBlur((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->updateWindowIcon(); break;
        case 19: _t->updateWindowCaption(); break;
        case 20: _t->updateProgress(); break;
        case 21: _t->openUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 22: _t->setProfileList((*reinterpret_cast<std::add_pointer_t<ProfileList*>>(_a[1]))); break;
        case 23: _t->setContainerList((*reinterpret_cast<std::add_pointer_t<ContainerList*>>(_a[1]))); break;
        case 24: _t->applyKonsoleSettings(); break;
        case 25: _t->applyThemeProfile(); break;
        case 26: _t->activationRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->updateUseTransparency(); break;
        case 28: _t->viewFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QExplicitlySharedDataPointer<Profile> & , const QString & , const ContainerInfo & )>(_a, &MainWindow::newWindowRequest, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(ViewSplitter * , QHash<TerminalDisplay*,Session*> )>(_a, &MainWindow::terminalsDetached, 1))
            return;
    }
}

const QMetaObject *Konsole::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konsole::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Konsole::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void Konsole::MainWindow::newWindowRequest(const QExplicitlySharedDataPointer<Profile> & _t1, const QString & _t2, const ContainerInfo & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Konsole::MainWindow::terminalsDetached(ViewSplitter * _t1, QHash<TerminalDisplay*,Session*> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
