/****************************************************************************
** Meta object code from reading C++ file 'ProfileList.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konsole-26.07.90/src/profile/ProfileList.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProfileList.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Konsole11ProfileListE_t {};
} // unnamed namespace

template <> constexpr inline auto Konsole::ProfileList::qt_create_metaobjectdata<qt_meta_tag_ZN7Konsole11ProfileListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konsole::ProfileList",
        "profileSelected",
        "",
        "Profile::Ptr",
        "profile",
        "actionsChanged",
        "QList<QAction*>",
        "actions",
        "triggered",
        "QAction*",
        "action",
        "profileChanged",
        "shortcutChanged",
        "QKeySequence",
        "sequence",
        "addShortcutAction",
        "removeShortcutAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profileSelected'
        QtMocHelpers::SignalData<void(const Profile::Ptr &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'actionsChanged'
        QtMocHelpers::SignalData<void(const QList<QAction*> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'triggered'
        QtMocHelpers::SlotData<void(QAction *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'profileChanged'
        QtMocHelpers::SlotData<void(const Profile::Ptr &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'shortcutChanged'
        QtMocHelpers::SlotData<void(const Profile::Ptr &, const QKeySequence &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'addShortcutAction'
        QtMocHelpers::SlotData<void(const Profile::Ptr &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'removeShortcutAction'
        QtMocHelpers::SlotData<void(const Profile::Ptr &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProfileList, qt_meta_tag_ZN7Konsole11ProfileListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konsole::ProfileList::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole11ProfileListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole11ProfileListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Konsole11ProfileListE_t>.metaTypes,
    nullptr
} };

void Konsole::ProfileList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profileSelected((*reinterpret_cast<std::add_pointer_t<Profile::Ptr>>(_a[1]))); break;
        case 1: _t->actionsChanged((*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[1]))); break;
        case 2: _t->triggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 3: _t->profileChanged((*reinterpret_cast<std::add_pointer_t<Profile::Ptr>>(_a[1]))); break;
        case 4: _t->shortcutChanged((*reinterpret_cast<std::add_pointer_t<Profile::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[2]))); break;
        case 5: _t->addShortcutAction((*reinterpret_cast<std::add_pointer_t<Profile::Ptr>>(_a[1]))); break;
        case 6: _t->removeShortcutAction((*reinterpret_cast<std::add_pointer_t<Profile::Ptr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProfileList::*)(const Profile::Ptr & )>(_a, &ProfileList::profileSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileList::*)(const QList<QAction*> & )>(_a, &ProfileList::actionsChanged, 1))
            return;
    }
}

const QMetaObject *Konsole::ProfileList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konsole::ProfileList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole11ProfileListE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konsole::ProfileList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Konsole::ProfileList::profileSelected(const Profile::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Konsole::ProfileList::actionsChanged(const QList<QAction*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
