/****************************************************************************
** Meta object code from reading C++ file 'EditProfileDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konsole-26.07.90/src/widgets/EditProfileDialog.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'EditProfileDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Konsole17EditProfileDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Konsole::EditProfileDialog::qt_create_metaobjectdata<qt_meta_tag_ZN7Konsole17EditProfileDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konsole::EditProfileDialog",
        "accept",
        "",
        "reject",
        "sizeHint",
        "QSize",
        "preparePage",
        "KPageWidgetItem*",
        "current",
        "before",
        "save",
        "selectInitialDir",
        "selectIcon",
        "profileNameChanged",
        "name",
        "initialDirChanged",
        "dir",
        "startInSameDir",
        "inheritContainerContext",
        "containerComboChanged",
        "index",
        "commandChanged",
        "command",
        "semanticUpDown",
        "semanticInputClick",
        "enable",
        "tabTitleFormatChanged",
        "format",
        "remoteTabTitleFormatChanged",
        "tabColorChanged",
        "QColor",
        "color",
        "tabActivityColorChanged",
        "silenceSecondsChanged",
        "terminalColumnsEntryChanged",
        "terminalRowsEntryChanged",
        "showTerminalSizeHint",
        "setDimWhenInactive",
        "setDimValue",
        "value",
        "setBorderWhenActive",
        "setFocusBorderColor",
        "showEnvironmentEditor",
        "setAntialiasText",
        "setBoldIntense",
        "useFontLineCharacters",
        "useFontBrailleCharacters",
        "newColorScheme",
        "editColorScheme",
        "saveColorScheme",
        "ColorScheme",
        "scheme",
        "isNewScheme",
        "removeColorScheme",
        "setVerticalLine",
        "setVerticalLineColumn",
        "focusBorderColorChanged",
        "toggleBlinkingCursor",
        "toggleAnimatingCursor",
        "setCursorShape",
        "autoCursorColor",
        "customCursorColor",
        "customCursorColorChanged",
        "customCursorTextColorChanged",
        "terminalMarginChanged",
        "margin",
        "lineSpacingChanged",
        "setTerminalCenter",
        "togglebidiRendering",
        "togglebidiTableDirOverride",
        "togglebidiLineLTR",
        "gotNewColorSchemes",
        "QList<KNSCore::Entry>",
        "changedEntries",
        "resetColorScheme",
        "colorSchemeSelected",
        "previewColorScheme",
        "QModelIndex",
        "showFontDialog",
        "showEmojiFontDialog",
        "toggleMouseWheelZoom",
        "historyModeChanged",
        "Enum::HistoryModeEnum",
        "mode",
        "historySizeChanged",
        "scrollFullPage",
        "scrollHalfPage",
        "toggleHighlightScrolledLines",
        "toggleReflowLines",
        "toggleScrollbarMarkerColor",
        "toggleScrollbarMarkerSize",
        "pSize",
        "toggleScrollbarSearchLineColor",
        "toggleScrollbarSearchLineOpacity",
        "opacity",
        "editKeyBinding",
        "newKeyBinding",
        "keyBindingSelected",
        "removeKeyBinding",
        "resetKeyBindings",
        "toggleUnderlineFiles",
        "toggleUnderlineLinks",
        "toggleOpenLinksByDirectClick",
        "textEditorCmdEditLineChanged",
        "text",
        "toggleCtrlRequiredForDrag",
        "toggleDropUrlsAsText",
        "toggleCopyTextToClipboard",
        "toggleCopyTextAsHTML",
        "toggleTrimLeadingSpacesInSelectedText",
        "toggleTrimTrailingSpacesInSelectedText",
        "toggleClearSelectionOnCopy",
        "pasteFromX11Selection",
        "pasteFromClipboard",
        "rightClickPasteDisabled",
        "rightClickPasteFromClipboard",
        "rightClickPasteFromX11Selection",
        "toggleAlternateScrolling",
        "toggleAllowColorFilter",
        "toggleAllowMouseTracking",
        "allow",
        "TripleClickModeChanged",
        "wordCharactersChanged",
        "toggleBlinkingText",
        "toggleFlowControl",
        "updateUrlHintsModifier",
        "toggleReverseUrlHints",
        "setAutoSaveInterval",
        "setDefaultCodec",
        "codec",
        "setTextEditorCombo",
        "Profile::Ptr",
        "profile",
        "toggleAllowLinkEscapeSequence",
        "linkEscapeSequenceTextsChanged",
        "peekPrimaryKeySequenceChanged",
        "toggleWordMode",
        "toggleWordModeAttr",
        "toggleWordModeAscii",
        "toggleWordModeBrahmic",
        "toggleWordModeCoding",
        "toggleIgnoreWcWidth",
        "ignore",
        "toggleFontHinting",
        "enableHinting",
        "toggleBadgeEnabled",
        "badgeTextChanged",
        "badgeFontFamilyChanged",
        "family",
        "badgeFontSizeChanged",
        "size",
        "badgeColorChanged",
        "badgeTextOnlyChanged",
        "textOnly",
        "badgeTransparencyChanged",
        "transparency",
        "toggleKittyKeyboard"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sizeHint'
        QtMocHelpers::SlotData<QSize() const>(4, 2, QMC::AccessPrivate, 0x80000000 | 5),
        // Slot 'preparePage'
        QtMocHelpers::SlotData<void(KPageWidgetItem *, KPageWidgetItem *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
        // Slot 'preparePage'
        QtMocHelpers::SlotData<void(KPageWidgetItem *)>(6, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectInitialDir'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectIcon'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'profileNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'initialDirChanged'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'startInSameDir'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'inheritContainerContext'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'containerComboChanged'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'commandChanged'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'semanticUpDown'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'semanticInputClick'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'tabTitleFormatChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'remoteTabTitleFormatChanged'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'tabColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'tabActivityColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'silenceSecondsChanged'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'terminalColumnsEntryChanged'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'terminalRowsEntryChanged'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'showTerminalSizeHint'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setDimWhenInactive'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setDimValue'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'setBorderWhenActive'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setFocusBorderColor'
        QtMocHelpers::SlotData<void(const QColor &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'showEnvironmentEditor'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAntialiasText'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'setBoldIntense'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'useFontLineCharacters'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'useFontBrailleCharacters'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'newColorScheme'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editColorScheme'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveColorScheme'
        QtMocHelpers::SlotData<void(const ColorScheme &, bool)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 }, { QMetaType::Bool, 52 },
        }}),
        // Slot 'removeColorScheme'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setVerticalLine'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setVerticalLineColumn'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'focusBorderColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'toggleBlinkingCursor'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleAnimatingCursor'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setCursorShape'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'autoCursorColor'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'customCursorColor'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'customCursorColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Slot 'customCursorTextColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Slot 'terminalMarginChanged'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 65 },
        }}),
        // Slot 'lineSpacingChanged'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setTerminalCenter'
        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'togglebidiRendering'
        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'togglebidiTableDirOverride'
        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'togglebidiLineLTR'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'gotNewColorSchemes'
        QtMocHelpers::SlotData<void(const QList<KNSCore::Entry> &)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 72, 73 },
        }}),
        // Slot 'resetColorScheme'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'colorSchemeSelected'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'previewColorScheme'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 77, 20 },
        }}),
        // Slot 'showFontDialog'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showEmojiFontDialog'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMouseWheelZoom'
        QtMocHelpers::SlotData<void(bool)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'historyModeChanged'
        QtMocHelpers::SlotData<void(Enum::HistoryModeEnum)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 82, 83 },
        }}),
        // Slot 'historySizeChanged'
        QtMocHelpers::SlotData<void(int)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'scrollFullPage'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollHalfPage'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleHighlightScrolledLines'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'toggleReflowLines'
        QtMocHelpers::SlotData<void(bool)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'toggleScrollbarMarkerColor'
        QtMocHelpers::SlotData<void(QColor)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'toggleScrollbarMarkerSize'
        QtMocHelpers::SlotData<void(double)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 91 },
        }}),
        // Slot 'toggleScrollbarSearchLineColor'
        QtMocHelpers::SlotData<void(QColor)>(92, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'toggleScrollbarSearchLineOpacity'
        QtMocHelpers::SlotData<void(int)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 94 },
        }}),
        // Slot 'editKeyBinding'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newKeyBinding'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'keyBindingSelected'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeKeyBinding'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetKeyBindings'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleUnderlineFiles'
        QtMocHelpers::SlotData<void(bool)>(100, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'toggleUnderlineLinks'
        QtMocHelpers::SlotData<void(bool)>(101, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleOpenLinksByDirectClick'
        QtMocHelpers::SlotData<void(bool)>(102, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'textEditorCmdEditLineChanged'
        QtMocHelpers::SlotData<void(const QString &)>(103, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 104 },
        }}),
        // Slot 'toggleCtrlRequiredForDrag'
        QtMocHelpers::SlotData<void(bool)>(105, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleDropUrlsAsText'
        QtMocHelpers::SlotData<void(bool)>(106, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleCopyTextToClipboard'
        QtMocHelpers::SlotData<void(bool)>(107, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleCopyTextAsHTML'
        QtMocHelpers::SlotData<void(bool)>(108, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleTrimLeadingSpacesInSelectedText'
        QtMocHelpers::SlotData<void(bool)>(109, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleTrimTrailingSpacesInSelectedText'
        QtMocHelpers::SlotData<void(bool)>(110, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleClearSelectionOnCopy'
        QtMocHelpers::SlotData<void(bool)>(111, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'pasteFromX11Selection'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pasteFromClipboard'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rightClickPasteDisabled'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rightClickPasteFromClipboard'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rightClickPasteFromX11Selection'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleAlternateScrolling'
        QtMocHelpers::SlotData<void(bool)>(117, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'toggleAllowColorFilter'
        QtMocHelpers::SlotData<void(bool)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'toggleAllowMouseTracking'
        QtMocHelpers::SlotData<void(bool)>(119, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 120 },
        }}),
        // Slot 'TripleClickModeChanged'
        QtMocHelpers::SlotData<void(int)>(121, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'wordCharactersChanged'
        QtMocHelpers::SlotData<void(const QString &)>(122, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'toggleBlinkingText'
        QtMocHelpers::SlotData<void(bool)>(123, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleFlowControl'
        QtMocHelpers::SlotData<void(bool)>(124, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateUrlHintsModifier'
        QtMocHelpers::SlotData<void(bool)>(125, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleReverseUrlHints'
        QtMocHelpers::SlotData<void(bool)>(126, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setAutoSaveInterval'
        QtMocHelpers::SlotData<void(int)>(127, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setDefaultCodec'
        QtMocHelpers::SlotData<void(const QByteArray &)>(128, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 129 },
        }}),
        // Slot 'setTextEditorCombo'
        QtMocHelpers::SlotData<void(const Profile::Ptr &)>(130, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 131, 132 },
        }}),
        // Slot 'toggleAllowLinkEscapeSequence'
        QtMocHelpers::SlotData<void(bool)>(133, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'linkEscapeSequenceTextsChanged'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'peekPrimaryKeySequenceChanged'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleWordMode'
        QtMocHelpers::SlotData<void(bool)>(136, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'toggleWordModeAttr'
        QtMocHelpers::SlotData<void(bool)>(137, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'toggleWordModeAscii'
        QtMocHelpers::SlotData<void(bool)>(138, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'toggleWordModeBrahmic'
        QtMocHelpers::SlotData<void(bool)>(139, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'toggleWordModeCoding'
        QtMocHelpers::SlotData<void(bool)>(140, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'toggleIgnoreWcWidth'
        QtMocHelpers::SlotData<void(bool)>(141, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 142 },
        }}),
        // Slot 'toggleFontHinting'
        QtMocHelpers::SlotData<void(bool)>(143, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 144 },
        }}),
        // Slot 'toggleBadgeEnabled'
        QtMocHelpers::SlotData<void(bool)>(145, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'badgeTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(146, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 104 },
        }}),
        // Slot 'badgeFontFamilyChanged'
        QtMocHelpers::SlotData<void(const QString &)>(147, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 148 },
        }}),
        // Slot 'badgeFontSizeChanged'
        QtMocHelpers::SlotData<void(int)>(149, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 150 },
        }}),
        // Slot 'badgeColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(151, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'badgeTextOnlyChanged'
        QtMocHelpers::SlotData<void(bool)>(152, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 153 },
        }}),
        // Slot 'badgeTransparencyChanged'
        QtMocHelpers::SlotData<void(int)>(154, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 155 },
        }}),
        // Slot 'toggleKittyKeyboard'
        QtMocHelpers::SlotData<void(bool)>(156, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditProfileDialog, qt_meta_tag_ZN7Konsole17EditProfileDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konsole::EditProfileDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<KPageDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole17EditProfileDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole17EditProfileDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Konsole17EditProfileDialogE_t>.metaTypes,
    nullptr
} };

void Konsole::EditProfileDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditProfileDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accept(); break;
        case 1: _t->reject(); break;
        case 2: { QSize _r = _t->sizeHint();
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->preparePage((*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[2]))); break;
        case 4: _t->preparePage((*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[1]))); break;
        case 5: _t->save(); break;
        case 6: _t->selectInitialDir(); break;
        case 7: _t->selectIcon(); break;
        case 8: _t->profileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->initialDirChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->startInSameDir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->inheritContainerContext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->containerComboChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->commandChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->semanticUpDown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->semanticInputClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->tabTitleFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->remoteTabTitleFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->tabColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 19: _t->tabActivityColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 20: _t->silenceSecondsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->terminalColumnsEntryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->terminalRowsEntryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->showTerminalSizeHint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->setDimWhenInactive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setDimValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setBorderWhenActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setFocusBorderColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 28: _t->showEnvironmentEditor(); break;
        case 29: _t->setAntialiasText((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setBoldIntense((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->useFontLineCharacters((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->useFontBrailleCharacters((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->newColorScheme(); break;
        case 34: _t->editColorScheme(); break;
        case 35: _t->saveColorScheme((*reinterpret_cast<std::add_pointer_t<ColorScheme>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: _t->removeColorScheme(); break;
        case 37: _t->setVerticalLine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->setVerticalLineColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->focusBorderColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 40: _t->toggleBlinkingCursor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->toggleAnimatingCursor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->setCursorShape((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->autoCursorColor(); break;
        case 44: _t->customCursorColor(); break;
        case 45: _t->customCursorColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 46: _t->customCursorTextColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 47: _t->terminalMarginChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->lineSpacingChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->setTerminalCenter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->togglebidiRendering((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: _t->togglebidiTableDirOverride((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->togglebidiLineLTR((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: _t->gotNewColorSchemes((*reinterpret_cast<std::add_pointer_t<QList<KNSCore::Entry>>>(_a[1]))); break;
        case 54: _t->resetColorScheme(); break;
        case 55: _t->colorSchemeSelected(); break;
        case 56: _t->previewColorScheme((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 57: _t->showFontDialog(); break;
        case 58: _t->showEmojiFontDialog(); break;
        case 59: _t->toggleMouseWheelZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->historyModeChanged((*reinterpret_cast<std::add_pointer_t<Enum::HistoryModeEnum>>(_a[1]))); break;
        case 61: _t->historySizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 62: _t->scrollFullPage(); break;
        case 63: _t->scrollHalfPage(); break;
        case 64: _t->toggleHighlightScrolledLines((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 65: _t->toggleReflowLines((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 66: _t->toggleScrollbarMarkerColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 67: _t->toggleScrollbarMarkerSize((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 68: _t->toggleScrollbarSearchLineColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 69: _t->toggleScrollbarSearchLineOpacity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 70: _t->editKeyBinding(); break;
        case 71: _t->newKeyBinding(); break;
        case 72: _t->keyBindingSelected(); break;
        case 73: _t->removeKeyBinding(); break;
        case 74: _t->resetKeyBindings(); break;
        case 75: _t->toggleUnderlineFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 76: _t->toggleUnderlineLinks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 77: _t->toggleOpenLinksByDirectClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 78: _t->textEditorCmdEditLineChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 79: _t->toggleCtrlRequiredForDrag((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 80: _t->toggleDropUrlsAsText((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 81: _t->toggleCopyTextToClipboard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 82: _t->toggleCopyTextAsHTML((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 83: _t->toggleTrimLeadingSpacesInSelectedText((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 84: _t->toggleTrimTrailingSpacesInSelectedText((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 85: _t->toggleClearSelectionOnCopy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 86: _t->pasteFromX11Selection(); break;
        case 87: _t->pasteFromClipboard(); break;
        case 88: _t->rightClickPasteDisabled(); break;
        case 89: _t->rightClickPasteFromClipboard(); break;
        case 90: _t->rightClickPasteFromX11Selection(); break;
        case 91: _t->toggleAlternateScrolling((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 92: _t->toggleAllowColorFilter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 93: _t->toggleAllowMouseTracking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 94: _t->TripleClickModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 95: _t->wordCharactersChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 96: _t->toggleBlinkingText((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 97: _t->toggleFlowControl((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 98: _t->updateUrlHintsModifier((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 99: _t->toggleReverseUrlHints((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 100: _t->setAutoSaveInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 101: _t->setDefaultCodec((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 102: _t->setTextEditorCombo((*reinterpret_cast<std::add_pointer_t<Profile::Ptr>>(_a[1]))); break;
        case 103: _t->toggleAllowLinkEscapeSequence((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 104: _t->linkEscapeSequenceTextsChanged(); break;
        case 105: _t->peekPrimaryKeySequenceChanged(); break;
        case 106: _t->toggleWordMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 107: _t->toggleWordModeAttr((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 108: _t->toggleWordModeAscii((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 109: _t->toggleWordModeBrahmic((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 110: _t->toggleWordModeCoding((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 111: _t->toggleIgnoreWcWidth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 112: _t->toggleFontHinting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 113: _t->toggleBadgeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 114: _t->badgeTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 115: _t->badgeFontFamilyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 116: _t->badgeFontSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 117: _t->badgeColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 118: _t->badgeTextOnlyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 119: _t->badgeTransparencyChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 120: _t->toggleKittyKeyboard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPageWidgetItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPageWidgetItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Konsole::EditProfileDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konsole::EditProfileDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole17EditProfileDialogE_t>.strings))
        return static_cast<void*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int Konsole::EditProfileDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 121)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 121;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 121)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 121;
    }
    return _id;
}
QT_WARNING_POP
