/****************************************************************************
** Meta object code from reading C++ file 'Profile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konsole-26.07.90/src/profile/Profile.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Profile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Konsole7ProfileE_t {};
} // unnamed namespace

template <> constexpr inline auto Konsole::Profile::qt_create_metaobjectdata<qt_meta_tag_ZN7Konsole7ProfileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konsole::Profile",
        "Property",
        "Path",
        "Name",
        "UntranslatedName",
        "Icon",
        "Command",
        "Arguments",
        "Environment",
        "Directory",
        "LocalTabTitleFormat",
        "RemoteTabTitleFormat",
        "ShowTerminalSizeHint",
        "DimWhenInactive",
        "BorderWhenActive",
        "InvertSelectionColors",
        "Font",
        "ColorScheme",
        "KeyBindings",
        "HistoryMode",
        "HistorySize",
        "ScrollBarPosition",
        "ScrollFullPage",
        "HighlightScrolledLines",
        "ReflowLines",
        "BidiRenderingEnabled",
        "BidiLineLTR",
        "BidiTableDirOverride",
        "BlinkingTextEnabled",
        "FlowControlEnabled",
        "LineSpacing",
        "BlinkingCursorEnabled",
        "AnimatingCursorEnabled",
        "UseCustomCursorColor",
        "CursorShape",
        "CustomCursorColor",
        "CustomCursorTextColor",
        "WordCharacters",
        "TripleClickMode",
        "UnderlineLinksEnabled",
        "UnderlineFilesEnabled",
        "TextEditorCmd",
        "TextEditorCmdCustom",
        "OpenLinksByDirectClickEnabled",
        "CtrlRequiredForDrag",
        "AutoCopySelectedText",
        "CopyTextAsHTML",
        "TrimLeadingSpacesInSelectedText",
        "TrimTrailingSpacesInSelectedText",
        "ClearSelectionOnCopy",
        "DropUrlsAsText",
        "PasteFromSelectionEnabled",
        "PasteFromClipboardEnabled",
        "MiddleClickPasteMode",
        "RightClickPasteMode",
        "DefaultEncoding",
        "AntiAliasFonts",
        "BoldIntense",
        "UseFontLineCharacters",
        "UseFontBrailleCharacters",
        "StartInCurrentSessionDir",
        "InheritContainerContext",
        "ContainerName",
        "SilenceSeconds",
        "BellMode",
        "TerminalColumns",
        "TerminalRows",
        "MenuIndex",
        "TerminalMargin",
        "TerminalCenter",
        "MouseWheelZoomEnabled",
        "AlternateScrolling",
        "UrlHintsModifiers",
        "ReverseUrlHints",
        "TabColor",
        "TabActivityColor",
        "DimValue",
        "FocusBorderColor",
        "AllowEscapedLinks",
        "EscapedLinksSchema",
        "VerticalLine",
        "VerticalLineAtChar",
        "PeekPrimaryKeySequence",
        "ColorFilterEnabled",
        "AllowMouseTracking",
        "SemanticHints",
        "SemanticUpDown",
        "SemanticInputClick",
        "EmojiFont",
        "MarkerColor",
        "MarkerSize",
        "SearchLineColor",
        "SearchLineOpacity",
        "LineNumbers",
        "ErrorBars",
        "ErrorBackground",
        "AlternatingBars",
        "AlternatingBackground",
        "WordMode",
        "WordModeAttr",
        "WordModeAscii",
        "WordModeBrahmic",
        "WordModeCoding",
        "IgnoreWcWidth",
        "FontHinting",
        "AutoSaveInterval",
        "BadgeText",
        "BadgeColor",
        "BadgeFontFamily",
        "BadgeFontSize",
        "BadgeEnabled",
        "BadgePosition",
        "BadgeTextOnly",
        "BadgeTransparency",
        "KittyKeyboardEnabled"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Property'
        QtMocHelpers::EnumData<enum Property>(1, 1, QMC::EnumFlags{}).add({
            {    2, Property::Path },
            {    3, Property::Name },
            {    4, Property::UntranslatedName },
            {    5, Property::Icon },
            {    6, Property::Command },
            {    7, Property::Arguments },
            {    8, Property::Environment },
            {    9, Property::Directory },
            {   10, Property::LocalTabTitleFormat },
            {   11, Property::RemoteTabTitleFormat },
            {   12, Property::ShowTerminalSizeHint },
            {   13, Property::DimWhenInactive },
            {   14, Property::BorderWhenActive },
            {   15, Property::InvertSelectionColors },
            {   16, Property::Font },
            {   17, Property::ColorScheme },
            {   18, Property::KeyBindings },
            {   19, Property::HistoryMode },
            {   20, Property::HistorySize },
            {   21, Property::ScrollBarPosition },
            {   22, Property::ScrollFullPage },
            {   23, Property::HighlightScrolledLines },
            {   24, Property::ReflowLines },
            {   25, Property::BidiRenderingEnabled },
            {   26, Property::BidiLineLTR },
            {   27, Property::BidiTableDirOverride },
            {   28, Property::BlinkingTextEnabled },
            {   29, Property::FlowControlEnabled },
            {   30, Property::LineSpacing },
            {   31, Property::BlinkingCursorEnabled },
            {   32, Property::AnimatingCursorEnabled },
            {   33, Property::UseCustomCursorColor },
            {   34, Property::CursorShape },
            {   35, Property::CustomCursorColor },
            {   36, Property::CustomCursorTextColor },
            {   37, Property::WordCharacters },
            {   38, Property::TripleClickMode },
            {   39, Property::UnderlineLinksEnabled },
            {   40, Property::UnderlineFilesEnabled },
            {   41, Property::TextEditorCmd },
            {   42, Property::TextEditorCmdCustom },
            {   43, Property::OpenLinksByDirectClickEnabled },
            {   44, Property::CtrlRequiredForDrag },
            {   45, Property::AutoCopySelectedText },
            {   46, Property::CopyTextAsHTML },
            {   47, Property::TrimLeadingSpacesInSelectedText },
            {   48, Property::TrimTrailingSpacesInSelectedText },
            {   49, Property::ClearSelectionOnCopy },
            {   50, Property::DropUrlsAsText },
            {   51, Property::PasteFromSelectionEnabled },
            {   52, Property::PasteFromClipboardEnabled },
            {   53, Property::MiddleClickPasteMode },
            {   54, Property::RightClickPasteMode },
            {   55, Property::DefaultEncoding },
            {   56, Property::AntiAliasFonts },
            {   57, Property::BoldIntense },
            {   58, Property::UseFontLineCharacters },
            {   59, Property::UseFontBrailleCharacters },
            {   60, Property::StartInCurrentSessionDir },
            {   61, Property::InheritContainerContext },
            {   62, Property::ContainerName },
            {   63, Property::SilenceSeconds },
            {   64, Property::BellMode },
            {   65, Property::TerminalColumns },
            {   66, Property::TerminalRows },
            {   67, Property::MenuIndex },
            {   68, Property::TerminalMargin },
            {   69, Property::TerminalCenter },
            {   70, Property::MouseWheelZoomEnabled },
            {   71, Property::AlternateScrolling },
            {   72, Property::UrlHintsModifiers },
            {   73, Property::ReverseUrlHints },
            {   74, Property::TabColor },
            {   75, Property::TabActivityColor },
            {   76, Property::DimValue },
            {   77, Property::FocusBorderColor },
            {   78, Property::AllowEscapedLinks },
            {   79, Property::EscapedLinksSchema },
            {   80, Property::VerticalLine },
            {   81, Property::VerticalLineAtChar },
            {   82, Property::PeekPrimaryKeySequence },
            {   83, Property::ColorFilterEnabled },
            {   84, Property::AllowMouseTracking },
            {   85, Property::SemanticHints },
            {   86, Property::SemanticUpDown },
            {   87, Property::SemanticInputClick },
            {   88, Property::EmojiFont },
            {   89, Property::MarkerColor },
            {   90, Property::MarkerSize },
            {   91, Property::SearchLineColor },
            {   92, Property::SearchLineOpacity },
            {   93, Property::LineNumbers },
            {   94, Property::ErrorBars },
            {   95, Property::ErrorBackground },
            {   96, Property::AlternatingBars },
            {   97, Property::AlternatingBackground },
            {   98, Property::WordMode },
            {   99, Property::WordModeAttr },
            {  100, Property::WordModeAscii },
            {  101, Property::WordModeBrahmic },
            {  102, Property::WordModeCoding },
            {  103, Property::IgnoreWcWidth },
            {  104, Property::FontHinting },
            {  105, Property::AutoSaveInterval },
            {  106, Property::BadgeText },
            {  107, Property::BadgeColor },
            {  108, Property::BadgeFontFamily },
            {  109, Property::BadgeFontSize },
            {  110, Property::BadgeEnabled },
            {  111, Property::BadgePosition },
            {  112, Property::BadgeTextOnly },
            {  113, Property::BadgeTransparency },
            {  114, Property::KittyKeyboardEnabled },
        }),
    };
    return QtMocHelpers::metaObjectData<Profile, qt_meta_tag_ZN7Konsole7ProfileE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konsole::Profile::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QSharedData>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole7ProfileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole7ProfileE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Konsole7ProfileE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
