// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "sshmanagerplugindebug.h"


Q_LOGGING_CATEGORY(SshManagerPluginDebug, "org.kde.konsole.plugin.sshmanager", QtInfoMsg)

